/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIEntityConverter.idl"

%{C++
#define NS_SAVEASCHARSET_CID { 0xcd233e0, 0x7a86, 0x11d3, { 0x91, 0x5c, 0x0, 0x60, 0x8, 0xa6, 0xed, 0xf6 } }
#define NS_SAVEASCHARSET_CONTRACTID "@mozilla.org/intl/saveascharset;1"
%}

[scriptable, uuid(33B87F70-7A9C-11d3-915C-006008A6EDF6)]
interface nsISaveAsCharset : nsISupports
{
  // attributes
  const unsigned long mask_Fallback                = 0x000000FF; // mask for fallback (8bits)
  const unsigned long mask_Entity                  = 0x00000300; // mask for entity (2bits)
  const unsigned long mask_CharsetFallback         = 0x00000400; // mask for charset fallback (1bit)

  const unsigned long attr_FallbackNone = 0;                   // no fall back for unconverted chars (skipped)
  const unsigned long attr_FallbackQuestionMark = 1;           // unconverted chars are replaced by '?'
  const unsigned long attr_FallbackEscapeU = 2;                // unconverted chars are escaped as \uxxxx
  const unsigned long attr_FallbackDecimalNCR = 3;             // unconverted chars are replaced by decimal NCR
  const unsigned long attr_FallbackHexNCR = 4;                 // unconverted chars are replaced by hex NCR

  const unsigned long attr_EntityNone = 0;                       // generate no Named Entity
  const unsigned long attr_EntityBeforeCharsetConv = 0x00000100; // generate Named Entity before charset conversion
  const unsigned long attr_EntityAfterCharsetConv =  0x00000200; // generate Named Entity after charset conversion

  const unsigned long attr_CharsetFallback        =  0x00000400; // fallback to other charset and restart the convesion


                                                               // default attribute for plain text
  const unsigned long attr_plainTextDefault = attr_FallbackNone + attr_EntityNone;               
  
                                                               // default attribute for html text
                                                               // generate entity before charset conversion, use decimal NCR
  const unsigned long attr_htmlTextDefault = attr_FallbackDecimalNCR + attr_EntityBeforeCharsetConv;

  readonly attribute string charset;                           // charset used for the conversion

  // set up charset, attribute and entity version 
  // see nsIEntityConverter.idl for possible value of entityVersion (entityNone for plain text).
  void Init(in string charset, in unsigned long attr, in unsigned long entityVersion);

  // convert UCS-2 html to target charset
  // may return the result code of the unicode converter (NS_ERROR_UENC_NOMAPPING)
  // if the attribute does not specify any fall back (e.g. attrPlainTextDefault)
	string Convert(in wstring inString);
};
